@@ -14,6 +14,7 @@ pub mod multimap;
 pub mod nrs;
 pub mod register;
 pub mod resolver;
+pub mod wallet;
 
 pub use crate::safeurl::*;
 pub use consts::DEFAULT_XORURL_BASE;
@@ -36,7 +37,7 @@ use crate::NodeConfig;
 
 use rand::rngs::OsRng;
 use safe_network::client::{Client, ClientConfig, DEFAULT_OPERATION_TIMEOUT};
-use safe_network::types::Keypair;
+use sn_interface::types::Keypair;
 use tracing::debug;
 
 use std::path::Path;
