@@ -21,7 +21,7 @@ mod errors;
 mod safeurl;
 
 // re-export these useful types from sn_data_types
-pub use safe_network::types::{
+pub use sn_interface::types::{
     BytesAddress, DataAddress, Keypair, PublicKey, RegisterAddress, SafeKeyAddress, Scope,
     SecretKey,
 };
